@@ -12,12 +12,16 @@ from yadm.fields.simple import (
     StringField,
 )
 
+from yadm.fields.email import EmailField
+
 from yadm.fields.datetime import DatetimeField
 from yadm.fields.decimal import DecimalField
+from yadm.fields.money import Money, MoneyField
 
 from yadm.fields.embedded import EmbeddedDocumentField
 
 from yadm.fields.list import ListField
 from yadm.fields.set import SetField
+from yadm.fields.map import MapField
 
 from yadm.fields.reference import ReferenceField
